#
# spec file for package rosegarden
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define vers    25.06

Name:           rosegarden
Version:        25.06
Release:        1.1
License:        GPL-2.0-or-later
Summary:        Midi, Audio And Notation Editor
URL:            https://www.rosegardenmusic.com/
Group:          Productivity/Multimedia/Sound/Midi
Source0:        https://github.com/tedfelix/%{name}-official/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.xpm
Source2:        %{name}.1
# PATCH-FIX-OPENSUSE davejplater@gmail.com This patch fixes the file search paths for examples, templates and midi driver libraries.
Patch1:         rosegarden-fix-filepaths.patch
# PATCH-FIX-OPENSUSE ledest@gmail.com fix bashisms in scripts
Patch2:         rosegarden-14.02-fix-bashisms.patch
# PATCH-FIX-OPENSUSE port scripts/sf2rg.py to Python 3
Patch3:         scripts-sf2rg-python3.patch
BuildRequires:  alsa-devel
BuildRequires:  cmake >= 2.8.12
BuildRequires:  dssi-devel
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  ladspa-devel
BuildRequires:  libjack-devel
BuildRequires:  liblo-devel
BuildRequires:  liblrdf-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libsndfile-devel
BuildRequires:  lilypond-fonts-common >= 2.20
BuildRequires:  lirc-devel
BuildRequires:  pkg-config
BuildRequires:  zstd
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(lilv-0)
#BuildRequires:  pkgconfig(libxml++-2.6)
BuildRequires:  shared-mime-info
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(libxml-2.0)
Requires:       dssi
Requires:       ladspa
Requires:       ladspa-swh-plugins
Requires:       lilypond-fonts-common >= 2.20
Requires:       xsynth-dssi
Recommends:     fluidsynth-dssi
Recommends:     jack
Recommends:     qsynth
Icon:           rosegarden.xpm
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExcludeArch:    i586 i686

%description
Rosegarden is a well-rounded audio and MIDI sequencer,
score editor, and general-purpose music composition and
editing environment. Rosegarden is an easy-to-learn,
attractive application that runs on Linux, ideal for
composers, musicians, music students, and small studio or
home recording environments.

%prep
%setup -q -n %{name}-official-%{version}
%autopatch -p1

# When we build svn we need to execute bootstrap.sh
#sh bootstrap.sh
for i in `grep -rl "/usr/bin/env python"`;do sed -i '1s/^#!.*/#!\/usr\/bin\/python3/' ${i} ;done
for i in `grep -rl "/usr/bin/python"`;do sed -i '1s/^#!.*/#!\/usr\/bin\/python3/' ${i} ;done

%build
#export DEBUG_LADSPA
#export QTDIR=/usr/
export CFLAGS="%{optflags} -fno-strict-aliasing -ggdb"
export CXXFLAGS="$CFLAGS"
# -fmessage-length=0 -O2 -fno-strict-aliasing -Wall -D_FORTIFY_SOURCE=2 -fstack-protector -funwind-tables -fasynchronous-unwind-tables
# Now uses cmake
#%%configure --enable-debug --localedir=%%{_datadir}/%%{name}/locale/
%cmake \
       -DCMAKE_INSTALL_LOCALEDIR:PATH=%{_datadir}/locale/

#make svnheader
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_datadir}/%{name}/scripts
cp -p -r scripts/* %{buildroot}%{_datadir}/%{name}/scripts/
cp -r data/* %{buildroot}%{_datadir}/%{name}/

pushd build
%make_install
popd
rm -rf %{buildroot}%{_datadir}/%{name}/desktop
rm -rf %{buildroot}%{_datadir}/%{name}/mime
rm -f %{buildroot}%{_datadir}/%{name}/*.cpp
rm -f %{buildroot}%{_datadir}/%{name}/*.o
chmod 755 %{buildroot}%{_datadir}/%{name}/scripts/*
chmod 644 %{buildroot}%{_datadir}/%{name}/scripts/lircrc.rosegarden
chmod 644 %{buildroot}%{_datadir}/%{name}/scripts/README
chmod 644 %{buildroot}%{_datadir}/%{name}/scripts/color-list
#chmod 644 %%{buildroot}%%{_datadir}/%%{name}/scripts/simple-makefile
rm -f %{buildroot}%{_datadir}/%{name}/scripts/svn-to-hg-and-git.sh
install -D -m 0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/pixmaps/%{name}.xpm"
%suse_update_desktop_file %{buildroot}/%{_datadir}/applications/com.rosegardenmusic.%{name}.desktop
#This is a man page made by help2man to satisfy factories hunger for one /usr/bin/ one man page.
mkdir -p %{buildroot}%{_mandir}/man1
install -D -m 0644 "%{SOURCE2}" "%{buildroot}%{_mandir}/man1/"
%fdupes -s %{buildroot}%{_datadir}/

%files
%defattr(-,root,root)
%doc AUTHORS README.md
%license COPYING
%dir %{_datadir}/metainfo
%dir %{_datadir}/%{name}/
%dir %{_datadir}/%{name}/autoload
%dir %{_datadir}/%{name}/chords
%dir %{_datadir}/%{name}/examples
%dir %{_datadir}/%{name}/fonts
%dir %{_datadir}/%{name}/library
%dir %{_datadir}/%{name}/locale
%dir %{_datadir}/%{name}/profile
%dir %{_datadir}/%{name}/scripts
%dir %{_datadir}/%{name}/styles
%dir %{_datadir}/%{name}/templates
%{_datadir}/icons/hicolor/*
%{_datadir}/pixmaps/%{name}.xpm
%{_datadir}/applications/com.rosegardenmusic.%{name}.desktop
%{_datadir}/metainfo/%{name}.appdata.xml
%{_bindir}/%{name}
%{_libdir}/lib%{name}private.so
%{_mandir}/man1/*
%{_datadir}/%{name}/*
%{_datadir}/mime/packages/%{name}.xml

%changelog
* Thu Jun  5 2025 Konstantin Voinov <kv@kott.no-ip.biz>
- fix warning in .spec
- update to 25.06
  * Bug Fixes
  * Lilypond: Fix the missing dot in property paths
    (LilyPond > 2.22). [3957c97969]
  * LV2: Add port sampleRate feature. [03d35cad0a]
  * Fixed Import Studio does not create new devices.
    Bug #1709. [4460f3521b]
  * Notation: Improve wording of highlight menu items. Bug #1708.
    [fdc4a3553c]
  * Event Viewer: Fix editor closes when editing triggered segments.
    [baeb7bad81]
  * Fix crash when deleting a triggered segment that was being
    edited with the notation or matrix editors. [c9cafc8ad8]
  * Fix wrong matrix editor window closed during segment split.
    Bug #1699. [80d3e70642]
  * Handle unsaved untitled autosave. Bug #1700. [cef44d35e3]
  * Matrix: Fix notes not sounding across a drag select. Bug #1697.
    [31ec6ed535]
  * Fix file dialogs forget paths. Feature Request #518. [5588528e46]
  * Fix crash when deleting a repeating segment opened in notation.
    Bug #1711. [119e4672d9]
  * Fix crash on Manage MIDI Devices window close. Debian #1091859.
    [64943ed3d8]
  * Fix crash on new document with bank editor open. Bug #1712.
    [f68d7dbcd6]
  * Fix missing time resolution warning. [6cbef7a786]
  * Instrument Parameters: Fix “Pan” control label cut off on the
    right. [8a78c11ae2]
  * Fix UI locks up when hitting “Record”. Bug #1713. [e8d16c4792]
  * Fix lyric editor with anacrusis [-1] problem. Bug #1715.
    [82045d5ca4]
  * Fix LV2 plugin JC303 not working. Bug #1714. [b341fd1ce3]
  * Add JACK stop at auto stop preference. Bug #1693. [c86d9ca6a7]
  * Tempo And Time Signature Editor: Fix tempo time change leftovers.
    Bug #1718. [017bdd1b60]
  * Fix potential crash when fast-forwarding or rewinding through a
    large composition while it is playing. Bug #1717. [01ddaca815]
  * Fix RG handling of jumping JACK transport. Bug #1721. [dc2062d42e]
  * LilyPond: Fix deprecation warnings while processing RG output.
    Bug #1675. [39bef99be1]
  * Matrix: Fix Add Tempo Change… not working. [b9a781ee9c]
  * Fix record input connections not happening. [38d50e757f]
  * Fix “toggle repeat” not handling mixed state in undo. Bug #1722.
    [1128116d13]
  * Fix transport dialog time/bars not updating on Tempo and Time
    Signature changes prior to the pointer position. [66401b64fc]
  * EventFilterDialog: Fix invalid read with “shortest” duration.
    [8068e139ba]
  * Fix LilyPond doesn't draw the repeat double bar when there
    are alternative endings. Bug #1676. [2e4b03092a]
  * New Features
  * Add an extra large track size in presentation preferences.
    Feature Request #524. [76247e4efd]
  * Add track label width to presentation preferences.
    Feature Request #525. [a401a663d4]
  * EditView: Add “Edit Triggered Segment” feature. [287a3765e1]
  * Add “Drag with dynamic modifiers (main window)” preference.
    [561db23422]
  * Constrained selection move in matrix editor.
    Feature Request #298. [4dfb643cf5]
  * Add preference for dynamic drag. Bug #1699. [561db23422]
  * Add “remove all from panel” command to the Manage Controllers
    dialog Edit menu. Feature Request #526. [68a2373fd4]
  * RPN and NRPN editing has been added to the Event List Editor.
    Feature Request #467. [bc567b76b3] [0a43462bdb]
  * MIDI Export: Add RPN and NRPN support. Feature Request #467.
    [f02f6bf8fb]
  * Event List Editor: Add filtering All On/Off button. [42f8635286]
  * LV2: Graduate out of beta. Enable by default. [90fccdab0a]
  * General Improvements
  * The Event List Editor has been rewritten.
  * The “Edit Event” dialog has been rewritten. This pops up when
    double-clicking on notes in Notation, the Matrix, and the
    Event List Editor.
  * Additional Contributions
  * Brazilian Portuguese translation. (Jeronimo Pellegrini)
  * Emu-Vintage-Keys.rgd (Hugo van Galen)
  * Roland-TD-7.rgd (Hugo van Galen)
  * Updated Polish translation (Grzegorz Pruchniakowski)
  * Updated German translation (Michael Stockinger)
  * Updated French translation (Yves Guillemot)
* Thu Feb  6 2025 Konstantin Voinov <kv@kott.no-ip.biz>
- update to 24.12.1
  * Fixed a crash when closing the Manage MIDI Devices window. Debian
    Bug #1091859. [544fbeea]
  * Fixed a crash when creating a new document (File > New) while the
    bank editor is up. Bug #1712. [77cd257d]
  * Fixed a crash when deleting a repeating segment that is being
    edited in notation. Bug #1711. [edff1c0a]
* Fri Dec 13 2024 Dave Plater <davejplater@gmail.com>
- Renamed rosegarden-10.10-filepaths.patch to
  rosegarden-fix-filepaths.patch to prevent future confusion.
* Thu Dec  5 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- enable LV2 beta support
- refresh rosegarden-10.10-filepaths.patch
- update .spec
- update to 24.12:
  * Bug Fixes
  * LV2: Fix link problem with no gtk2. [2e168f0d]
  * LV2: Add lv2 check for GUI library ok. [9cb306b3]
  * Manage MIDI Banks and Programs dialog now allows the same bank
  * MSB/LSB to be used for percussion and non-percussion banks on
  * the same device. Bug #1692.
  * Fix wrong ports being assigned on file load. Bug #1687.
  * [663099cc]
  * Fix autoscroll and highlighting behavior with multiple segments
  * on a track. Bug #1672.
  * Fix missing scroll bar on Instrument Parameters Bank dropdown.
  * Bug #1695. [295a2f7a]
  * Fix "turn repeats into copies" misses last segment. Bug #1696.
  * [afcf2f0e]
  * Fix shortcut order ignored. Bug #1702. [b1272a6d]
  * Fix unexpected cursor position when moving from note to note
  * on a bar with a clef or time signature. Bug #1704. [215b9d27]
  * Fix unexpected translation of bank and program names. Bug #1705.
  * [6dbd6bcd]
  * Fix unexpected Save As... directory. Feature #522. [15db9d10]
  * Fix broken tempo line in tempo ruler after adding a time
  * signature change. Bug #1706. [6a7ef89e]
  * Fix "Modify MIDI Filters" dialog does not mark document as changed.
  * Bug #1707. [4e505977]
  * Fix LV2 sfizz plugin support. [8fce0614]
  * Fix group box formatting issue in native/light theme. Bug #1678.
  * [d2df6376]
  * LV2: Fix crashes and locking related to atom buffers. [95b09722]
  * [be37b31e]
  * New Features
  * Make MIDI File Division value configurable for Export.
  * GH #9. [991e4839]
  * WAV export of audio and soft synth tracks.
  * File > Export > Export WAV File... [5b4d109e]
  * Apply interpretations to more than one segment.
  * Segment > Interpret... Feature #517. [b8a243a5]
  * LV2 support has been promoted to beta. [a602850c]
  * Advanced Looping has been promoted out of beta. [25bdbf69]
  * General Improvements
  * Manage MIDI Banks and Programs dialog is now full-featured and can
  * be used to edit every aspect of an .rgd device file.
  * Studio > Manage MIDI Devices > Banks...
  * Tempo and Time Signature Editor has been rewritten and improved.
  * Additional Contributions
  * Korg-M3-Factory-ALL.rgd (Chuck Elliot)
  * Korg-M1.rgd (Chuck Elliot)
  * Updated Polish translation (Grzegorz Pruchniakowski)
  * Updated Chinese translation (Icenowy Zheng)
  * Yamaha-MM6-MM8.rgd (Icenowy Zheng)
  * Yamaha-PSR-SX600.rgd (Huanyu Liu)
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 24.06:
  * txt2rgd.py: Fix MSB/LSB bug.  [d501a6f3]
  * Fix instrument selection for Ctrl+T (add track), file import
    and merge.
  * Disallow deletion of devices that are in use by tracks.
  * Use track names for segment names on MusicXML import.
  * Fix misplaced TimeWidget title in "Native (Light)" theme.
  * Fix an .rg parsing error related to softsynths.
  * Fix unobtainable segment presets and other preset issues.
  * Fix audio time stretching erasing all audio data in release
    build.
  * Fix submaster port count changing when changing the number of
    audio input ports.
  * Fix window focus problem when creating MIDI Devices.
  * Fix track instrument reset when editing banks.
  * Fix buffer overflow in notation editor.
  * Fix examples pointing to various audio paths causing unwanted
    directories to be created.
  * Fix slow refresh of note names in matrix.
  * Fix notation not selecting current segment notes on launch.
  * Fix UnusedAudioSelectionDialog column widths.
* Thu Dec 28 2023 Dirk Müller <dmueller@suse.com>
- update to 23.12:
  * Make punch-in also start recording.
  * Fix broken metronome flash in the transport.
  * Fix solo affects archived tracks.
  * Fix data loss when recording with loop on.
  * Prevent archived tracks from recording.
  * Fix arm status lost on save when archived.
  * Fix armed+archive recording after load.
  * Unarm archived Tracks when enforcing the arm rule: only one
    Track can be armed per Instrument.
  * Skip archived tracks when routing.
  * Fix refresh artifacts on the Matrix piano keyboard.
  * Fix error when rosegarden creates submaster outs.
  * Fixed potential race conditions with audio files.
  * Fix segment relabel dialog not showing original label.  Bug
  * Fixed events with data1 == 121 being dropped.  Bug #1663.
  * Fixed potential race conditions in the sequencer.
  * Fix removing the first note of a slurred group creates an
    unreachable rest.  Bug #1662.
  * Fix cannot beam a group beginning or ending with a dotted
    eighth note.  Bug #1666.
  * Fix segment parameter box displaying translation of the
    label.
  * Improved sub-beat highlighting in the Matrix editor.
  * Matrix editor preview note when hovering.
  * Add metronome and solo toggles to main menu.
  * Add MMC RECORD STROBE support.
  * Add a preference to include ALSA port numbers when making
    connections.
  * Use regexp for plugin blacklist.
  * Updated yoshimi.rgd.
* Sun Oct 29 2023 Dirk Müller <dmueller@suse.com>
- update to 23.06:
  * Fix crash related to static initialization order.
  * Fix bug #1047, beaming groups erroneous after merging notes.
  * Fix offset selection rectangle in Notation.  Bug #1444.
  * Fix time column widths in the Event Editor so that they don't
    need resizing on every launch.
  * Event filter dialog improvements and fixes.
  * Fix broken retrograde commands.
  * Lilypond: Fix volta/alternatives and lyrics.
  * Lilypond: Fix vertical alignment of verses.  Bug #1650.
  * Lilypond: Fix the printing of supplementary verses.
  * Lilypond: Fix multiple lyrics verses with repetition.
  * Lilypond: Fix the removing of an underscore at the end of a
    bar of lyrics.
  * Lilypond: Fix printing of verses is now working when voltas
    are unfolded.  [2eae089]
  * Lilypond: Fix bar number of verses in exported LilyPond
    files.
  * Fix timer preference coming up empty for selections after
    "HR timer".  [08748a6]
  * Fix paste problems in notation editor.  Bug #1651.  [457f3de]
  * Fix the LilyPond exporter autotest and update the baseline.
  * Fix crash in LilyPond exporter.  Bug #1640.  [a49712d]
  * Fix potential crash in the grid quantizer.  [4bdefd9]
  * Fix quantizer crash.  Bug #1654.  [56ca66c, a8e669d]
  * LilyPond: Fix a small bug related to numbers in the lyrics.
  * LilyPond: Fix for lyrics containing some special characters.
  * LilyPond: Fix the rendering of dash and underscore.
  * Fix missing parameter patterns in the Set Event Velocities
    dialog.
  * Matrix: Fix deleting too many notes with ruler present.  Bug
  * File > Merge dialogs now allow merging of multiple files.
  * View > Full Screen (F11) added to main window.  [a09103c]
  * Removed LEDs from archived tracks to make archived tracks
    easier to identify.  [a5f4131]
  * Matrix and Notation now offer snap to grid in the control
    rulers.
  * Add Ctrl+L shortcut for loop toggle.  Feature request #398.
  * Add new LilyPond versions.  [6c7f0ef]
  * Add "Remove notes smaller than X" field to grid quantizer.
  * Add "Remove articulations" to grid quantizer.  Feature
    request
* Tue Apr 18 2023 Max Lin <mlin@suse.com>
- Do not change the interpreter back to /usr/bin/python in sf2rg.py
  since scripts-sf2rg-python3.patch changed it to /usr/bin/python3
* Sun Apr  9 2023 davejplater@gmail.com
- Remove broken service and build Leap the same way as Tumbleweed.
- Download from chief developer's git hub site.
- Update to version 22.12.1:
  * The Rosegarden team is proud to announce the release of
  version 22.12 of Rosegarden, a MIDI sequencer that features a
  rich understanding of music notation along with basic support
  for digital audio.
  * Fix a crash caused by static initialization/link order.
    Bug #1647. [fa6eea8]
* Sat Jun 18 2022 dmueller@suse.com
- Update to version 22.06:
  * Improve Cut/Copy/Delete behavior in both the matrix and the
    notation editors.  Bug #1601.
  * "Scroll to Follow Playback" now remembers its last setting.
    Bug #1606.
  * Fixed a problem in notation with note selection and the blue
    indication.  Bug #1496.
  * Fixed volume and pan issues with older .rg files.  [51647cc]
  * Changed "For Notation" to "Exclude from Printing" in the
    Segment Parameters.
  * Fix confusing relative values in the "Insert Controller Sequence"
    dialog for volume and expression.  [14ff99a]
  * When changing the audio file path, the user is asked whether
    they want to move the audio files to the new location.  [71a62e6]
  * Fix stuck green preview note when switching modes.  Bug #1614.
  * Fix modified flag (*) not cleared when saving in notation.
    Bug #1617.
  * Fix RG stopping JACK transport when it shouldn't.  Bug #1051.
  * Fixed toolbar mode buttons not reflecting current state when
    Esc is pressed.  Bug #1615.  [f651345]
  * Notation: Fix green preview only available in one staff.
    Bug #1619.
  * Fixed issues when building with Qt6.  Feature Request #490.
  * Fixed bad rendering of note heads at small font sizes.  Bug #1484.
  * Fixed an endless loop in notation.  [7d734f7]
  * Improved management of audio file paths.  Bug #1283.  Feature
    Requests #494 and #495.
  * Simplify editing of audio instrument label in audio parameters
    panel.
  * Fixed display bugs in matrix editor.  Bug #1622.  [b4425d7]
  * Fix collapse notes in matrix.  Bug #1575.  [521ad4e]
  * Fix scrollbar issues in main window combo boxes.
    Feature Request #502.  [abdf22b]
  * Fix deletes in the tempo/time signature editor.  Bug #1628.
    [d55eea5]
  * Fix problems editing multiple segments in matrix.  Bug #1624.
    [8c1c6bc]
  * Notation: fix crash when segment is deleted.  Bug #1260.  [cf0a28d]
  * Notation: fix crash when undoing an Add Layer.  Bug #1260.
    [7a1b6bf]
  * Notation: fix note move issue.  Bug #1629.  [ba70dcf]
  * Fix lilypond export sometimes ignores time signature.  Bug #1620.
    [b7b16df]
  * Fix hairpins not always exported to LilyPond.  Bug #1620.
    [f57cbd9]
  * Fix missing "StartupWMClass" in .desktop file.  Bug #1635.
    [d3f5298]
  * Fix chord ruler.  Bug #1633.  [2b2fbf7]
  * Fix Event Filter dialog clearing selection on first launch.
    [52c2f90]
  * Fix lilypond common/cut time signatures.  Bug #1637.  [1c83f8b]
  * Fix a crash when unquantizing using the quantize combo box on the
    editors.  [329ab46]
  * Fix a crash when resizing segments.  Bug #1638.  [cdec668]
  * Fix a refresh issue when using the toolbar undo button.  [2a01178]
  * Stop playback at end of last segment.  (Preference.)
  * Advanced Looping.  (Experimental preference.)  Bug #1605.
  * Keyboard shortcut editor.  Feature Request #412.
* Mon Mar 28 2022 Dave Plater <davejplater@gmail.com>
- Enable Leap build again.
* Sun Mar 27 2022 dmueller@suse.com
- switch to the more performant zstd
- Update to version 21.12:
  * add label for keyboard layout
  * fix spelling and config group
  * SD: Tweak text and spacing
  * fix keyboard shortcuts on restart
  * remove labels from ShortcutDialog
  * mark keyboard translations
  * update keyboard translations
  * updates wiht multiselect and reset all
  * correct french keyboard for shortcut translations
  * add french keyboard for shortcut translations
  * Improve plugin debug logging
  * fix language problem for saving user shortcuts
  * allow for different keyboard layouts. Bug fixes
  * simplify ShortcutWarnDialog
  * fix warning bug
  * fix bug in addUserShortcut
  * use name in shortcut editor if no text is provided
  * catch escape key in ShortcutDelegate so esc can be set as a shortcut
  * limit to single key press in ShortcutDelegate
  * clean up ShortcutDialog
  * initial ShortcutDialog version with in-place keysequnece editing
  * enter does not accept ShortcutDisalog
  * Locate Audio Files: Turn off wait cursor
  * Implement missing audio file skip
  * FLD: Add Skip button
  * fix display bugs in matrix editor
  * Shortcuts: Reduce debugging output
  * Shortcuts: Update dialog message text
  * disable debug output and remove trailing white spaces
  * fix memory problem
  * add OK/Cancel to ShortcutDialog
  * Use QString::startsWith() for older Qt
  * cmake: Use find_library for JACK
  * Use QString::endsWith(), even better
  * layout for scrollbar
  * use QScrollArea in ShortcutWarnDialog
  * Use at() for compatibility with older Qt
  * additional features for ShortcutDialog
  * ShortcutWrnDialog functional
  * extend ShortcutWarnDialog
  * allow for removing all shortcuts
  * progress on ShortcutWarnDialog
  * fix bug reading shortcuts from xml
  * bug fixes
  * remove unused getShortcuts menthods
  * update shortcut edit
  * fix crash + tidy up
  * update ShortcutDialog for warnings
  * activate user shortcuts
  * change info data to key map
  * prepare for whortcut warnings
  * improve edit function
  * further progress on shortcut editor
  * further preparation for edit
  * add KeySequenceEdit
  * update preparation for edit
  * Allow cancel of forced save
  * Allow cancel when trying to record audio
  * AFM: Reset recent files on save
  * allow for shortcut translations
  * autoload: Add more controller colors
  * AIPP: Fix instrument label look and tooltip
  * Remove InstrumentAliasButton
  * AIFF: Edit label on click
  * make tree non editable
  * qt6: Correct use of QString::back()
  * German translation update from Michael Stockinger
  * CollapseNotesCommand - do not call makeNotesViable from matrix command
  * dialog showing all shortcuts
  * first attempt at a shortcut dialog
  * Change default audio path
  * Audio file not found, part 2
  * Cleanup
  * Audio file not found, part 1
  * Comments
  * XMLReader: Fix ignoring of parsing errors
  * Handle some less likely audio path use cases
  * AMF: Add support for double-dot (..)
  * Clean up tr()
  * AFM: Handle permissions issues on move
  * AudioPropertiesPage update part 2
  * AudioPropertiesPage update part 1
  * AFLD: Add custom location edit box
  * AFM: Support custom audio location
  * Add audio location preferences
  * Add Show AFLD to preferences
  * AFLD: Add "don't show" checkbox
  * set pointer position correctly in multi staff notation edit
  * AFLD: Persistence and location enum
  * Add AudioFileLocationDialog
  * Simplify
  * Cleanup
  * Renames
  * Cleanup
  * AFM: Clarify absolute vs. relative paths
  * Cleanup
  * AudioFileManager::save() first draft
  * Cleanup
  * Spline: Fix endless loop
  * set selected staff on note entry
  * use QMessageBox::information in RosegardenDocument.cpp
  * Add Yamaha PSR-220/230 device file
  * Add update-copyright script
  * Update copyright
  * remove warnings from qt 6.2.2
  * Pass QDebug by value to operator<<
  * NotationView: Esc should both unselect and go to select mode
  * Comments
  * Add txt2rgd.py to scripts
  * Cleanup
  * allow preview for all staffs in multiple noation edit
  * remove unused declaration in BeatsBarsDialog.h
  * Move peak files when moving audio
  * Add "move audio files" feature
  * Simplify
  * Comments and shuffling
  * APP: Detect non-writable audio file path
  * APP: Tweak math
  * reset range when looping is switched off (with new loop setting off)
  * Use QLocale to format numbers
  * Cleanup
  * Cleanup
  * Cleanup
  * Cleanup
  * optimization
  * Fix binary data in .rgd files
  * Fix Insert Controller Sequence dialog for volume
  * Update .rg XML file to use excludefromprinting
  * Fix incorrect class name
  * Rename SFNC -> SegmentExcludeFromPrintingCommand
  * SFNC: Invert ForNotation -> ExcludeFromPrinting
  * Change "For Notation" to "Exclude From Printing"
  * Fix volume and pan issues with older .rg files
  * fix bad debug output
  * remove staff argument to clearPreviewNote
  * German translation update from Michael Stockinger
  * Comments
  * Simplify: Use * instead of &
  * Remove unneeded RG_DEBUGs
  * Fix crash on Edit > Delete
  * Notation: Remove copy/cut controller events
  * Notation: Upgrade selection state behavior
  * set modified false before emitting documentModified
  * correct loopset
  * allow reinstate of loop from transport button
  * update default looping behaviour
  * Simplify
  * Notation: Add handling of two selections
  * Remove unused slotRulerSelectionChanged()
  * Remove BasicSelectionCommand class
  * Renames and comments
  * Okular exists in later versions than KDE 4 :-)
  * NoteItem - stop going to timy mode for small bounding rectangle
  * use min/max of time and notation time for renderElements calls
  * fix performance issues
  * do not stop jack transport for auto stop
  * defer looping when whole composition is looping
  * Renames
  * store playback tracking in document
  * Disable menu items when playing
  * TristateCheckBox: Add text ctor
  * NotationView: Revert delete to original behavior
  * Matrix: Remove copy/cut controller events
  * Matrix: Update selection when ruler tab changed
  * Matrix: Enable delete with any selection
  * Matrix: Upgrade selection state behavior
  * Simplify
  * Matrix: Add handling of two selections
  * Notation: Fix delete of selected ruler events
  * Matrix: Fix delete of selected ruler events
  * EraseCommand: Reference -> Pointer
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * RespellCommand: Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * RetrogradeInvertCmd: Remove BasicSelectionCommand
  * RetrogradeCommand: Remove BasicSelectionCommand
  * PlaceControllersCmd: Remove BasicSelectionCommand
  * MaskTriggerCommand: Remove BasicSelectionCommand
  * Remove BasicSelectionCommand
  * ClearTriggersCommand: Remove BasicSelectionCommand
  * ChangeVelocityCmd: Remove BasicSelectionCommand
  * AddDotCommand: Remove BasicSelectionCommand
  * Add EventSelection::empty()
  * Renames and simplification
  * Cleanup
  * Update version to 22.06
  * Updates for version 21.12
  * Update French tranlation
  * Fix crash when restoring rulers in editors
  * Update .ts files for 21.12 (scripts/make-ts)
  * cleanup debug
  * Try to loop entire song with setting
  * dynamic update for whole song loop
  * allow default looping of whole song
  * stop playback at end of last segment in a composition
* Wed Dec  1 2021 Dave Plater <davejplater@gmail.com>
- Create _service download file due to the spec file's download
  link becoming unreliable.
* Tue Nov 30 2021 Dave Plater <davejplater@gmail.com>
- Only recommend jack to allow pipewire jack to be installed.
* Wed Nov  3 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not build for i586: one of the main dependencies, lilypond, is
  not built for that arch.
* Sat Aug  7 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 21.06.1:
  * Fixed a crash when building with Qt 5.14 and above and
    running with multiple monitors (Bug #1599).
- Changes from version 21.06:
  * New features:
  - Clean Recent Files List in the preferences removes files
    that aren't present on the filesystem from the recent files
    list.
  - Preferences: Add send BS/PC/CCs while looping.
  - Added Segment label to Notation editor.
  - Matrix editor now preserves zoom factor and rulers for each
    Segment in the .rg file. Feature #486.
  - Notation editor now preserves rulers for each Segment in the
    .rg file. Feature #486.
  * Many bug fixes, see
    <https://rosegardenmusic.com/wiki/dev:21.06>.
* Fri Jul  9 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add scripts-sf2rg-python3.patch:
  - Port scripts/sf2rg.py to Python 3
* Mon Jan 18 2021 Dirk Müller <dmueller@suse.com>
- update to 20.12:
  * Fix QPainterPath compilation error (r15845)
  * Fixed several SysEx-related bugs in the Event editor (r15853)
  * SysEx load now remembers the last used path.
  * SysEx load now strips the F0/F7 bytes from the file when reading.
  * SysEx save now remembers the last used path.
  * SysEx save now fills in the FileDialog fields correctly.
  * SysEx save now adds the F0/F7 bytes to the data before saving.
  * Event Editor: Fix garbage on SysEx load error (r15855)
  * Event Parameter Dialog: Fix incorrect window title (r15857)
  * Fix length of notes added in percussion matrix (r15870)
  * Fix compilation error with Qt < 5.8 (r15872, r15896, others)
  * Fix issues with ALSA port name matching at file load (r15875,
    r15879, r15893-r15895, r15906, r15909)
  * Fix "&" in device name renders file unreadable.  Bug #1586. (r15886)
  * Matrix editor: Fix control rulers not appearing.  Bug #1543.
    (r15887)
  * Event editor: Fix crashes when editing (r15899, r15902, r15903)
  * Reduce connection check interval to 1 second (r15912)
  * Fix external controller port not working (r15915, r15916, r15919,
    r15927, r15929)
  * Fix ALSA timer selection persistence (r15936)
  * Fix disabled button text color (r15938)
  * Fix plugins not found (r15947)
  * Send proper CCs out the external controller port for motorized
    control surfaces.  Bug #1587. (r15952, r15954)
  * Fix unwanted CCs going out with old files.  Feature #482.  (r15961)
  * Fix slow load time with many segments.  Bug #1589.  (r16026)
  * Enable/Disable external controller port in the preferences (r15932,
    r15946, others)
  * Transport buttons (play, stop, etc...) on MIDI controllers are now
    supported so long as they use Pro Tools standard CCs (110-118).
    Feature #423.  (r15962-r15964)
  * Korg nanoKONTROL2 support (r15994-r16013, r16015, r16016, r16021)
  * Icon Loader (r15862-r15865, r15868)
  * New ExternalController class (r15922)
  * Preferences dialog (r15939-r15944)
  * ALSA MIDI interface (r15975-r15993)
- remove rosegarden-include-QPainterPath.patch (obsolete)
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 20.06:
  * Fixed multiple memory leaks (r15684, r15685, etc...)
  * Fixed 100%% CPU usage when drawing lines in the controller rulers,
    bug #1571 (r15705)
  * Fixed multiple invalid reads (r15707, r15708)
  * Increased the height of the loop ruler, feature #481 (r15718)
  * Fixed CCs not going out when playback begins in the middle of
    a segment, bug #1560 (r15735)
  * Fixed volume and pan CCs always going out even if the controllers
    were removed from the Device, feature #482 (r15750)
  * Stop sending CCs on ch10 when metronome muted, feature #482
    (r15751)
  * Fixed a problem with showing pitchbend ruler (r15771)
  * Made default for expression CC 127 instead of 100 (r15773)
  * Fixed a crash in Audio File Manager, bug #1576 (r15786)
  * Fixed a crash when importing .ly as X11/RG21, bug #1579 (r15806)
  * Fixed a crash on chords in pitch tracker, bug #1582 (r15835)
  * Track height can now be adjusted in the preferences, feature #479
    (r15710-r15712, r15737)
  * New Segment > Transpose by Semitones... available in the Segment
    Canvas, feature #480 (r15715)
  * Right-click can now be used in the loop ruler to set the loop,
    feature #481 (r15717)
  * The current segment label is now displayed in the Matrix editor
    when multiple segments have been selected for editing, feature
    [#470] (r15738-r15740)
  * Segment "For Notation" feature, bug #1578 (r15805)
  * Source distribution now includes these release notes in a
    CHANGELOG file.  The release notes will continue to be available
    on the wiki as well:
    https://www.rosegardenmusic.com/wiki/start#release_notes
  * PitchBend and Controller Sequence Dialog cleanup (r15662-r15684,
    r15696-r15701, etc...)
  * MappedEventBuffer cleanup (r15719-r15730)
  * Colour removal and ColourMap cleanup (r15795-r15803)
* Wed Jun  3 2020 Dave Plater <davejplater@gmail.com>
- Update to stable release is 19.12 and add patch to fix factory
  build: rosegarden-include-QPainterPath.patch.
- Upstream changes:
  * Fix synth plugin Send Test Note button (r15502)
  * Plugin Editor: Fix Send Test Note not sustaining (r15511)
  * Treat Left + Right mouse buttons as Middle button in Matrix and
  Notation editors (r15522)
  * Matrix: Fix no update on delete. Bug #1569. (r15616)
  * Fix missing metronome beat when expanding end during recording
  (r15621)
  * Style: Make QLineEdit text gray when disabled (r15631)
  * Fix transposing keys by interval (r15632)
  * RMW: Reduce calls to leave/enterActionState() (r15641)
  * Matrix Editor: Implement new auto-scroll behavior
  (r15525 - r15544)
  * Segment Canvas: Implement new auto-scroll behavior
  (r15546 - r15551)
  * Notation Editor: Implement new auto-scroll behavior
  (r15553 - r15555)
  * Add –convert command line option (r15607)
  * Add quaver triplet to standard quantizations (r15613)
  * Quantize: Add arbitrary quantization units. Feature #477(r15630)
  * Preferences: Allow dangerous operations during playback. Feature
  [#478]. (r15643, r15646, r15647, r15651)
  * Add ability to enable metronome during count-in and
  enable/disable during recording. Feature #453. (r15649)
  * Segment Parameters box cleanup (r15562 - r15597, r15604)
  * Replace FastVector with std::vector (r15609)
  * Quantize dialog cleanup (r15611 - r15614,
  r15617 - r15620, r15623 - r15629)
  * Preferences cleanup (r15634 - r15640)
* Thu May  7 2020 Dave Plater <davejplater@gmail.com>
- Correct lilypond font requirement for lilypond-2.20.0
* Wed Feb 19 2020 Dave Plater <davejplater@gmail.com>
- Require lilypond fonts instead of lilypond
* Wed Feb 19 2020 Dave Plater <davejplater@gmail.com>
- Remove all traces of python2.
* Mon Jun 10 2019 Dave Plater <davejplater@gmail.com>
- Update to rosegarden xerxes version 19.06
- Upstream changes:
  * Bug fixes:
  * Fix potential crashes during playback (r15422)
  * Fix crash when rescaling during playback (r15423)
  * Fix crash when splitting during playback (r15424)
  * Fix horizontal wheel scrolling on segment canvas
  (Bug #1561, r15430)
  * Fix horizontal wheel scrolling on Matrix and Notation editors
  (Bug #1561, r15432)
  * Enable High DPI Scaling (Bug #1565, r15444)
  * Roland-CM-64.rgd: Fix SN-U110-02 perc mappings (r15448)
  * Avoid using null pointers (Bug #1566, r15453)
  * Fix broken right edge auto scroll (Bug #1567, r15462, r15464)
  * Fix crash when adding a Track with no Devices (r15463)
  * Fix numerous memory leaks (r15466, r15470-5, r15477, r15479,
  r15481, etc…)
  * Fix build with Qt5.7 which doesn't have QSharedPointer(nullptr)
  (r15476)
  * SegmentParameterBox:Fix invalid memory access(Bug #1568, r15492)
  * Fix Qt 5.7 QSharedPointer/nullptr build issue (r15493)
  * New Features:
  * Add Ctrl+Space shortcut for record (r15482)
* Tue Dec 18 2018 davejplater@gmail.com
- Update to release 18.12
- Include newly added librosegardenprivate.so
- Upstream changes:
  * Fixed stuck notes on matrix editor (r15283)
  * Fixed some double-gzipped .rgd file (r15344, r15345)
  * Removed support for Qt4 (r15347)
  * Improved support for HiDPI displays (r15349, r15352)
  * Fixed crash when loading composition (r15355)
  * cmake 3.1 or above is now required (r15357)
  * Migrate to C++11 (r15361)
  * Use QLockFile for the document lock file, reducing leftover
  lock file warnings (r15373)
  * Show pointer position on new staff when clicking on a different
  staff (r15382)
  * Fixed wrong warning about “lyric” text type during export.
  (r15392)
  * Fixed some range checks in SequencerDataBlock (r15402)
* Tue Sep  4 2018 davejplater@gmail.com
- Update to release 18.06.
- Upstream changes:
  * Manage MIDI Banks and Programs window now uses a scroll area
  instead of tabs. (r15227)
  * Add “Reset to Defaults” button to Track Parameters. (r15241)
  * Standardized scroll wheel behavior. (Feature #445, r15245,
  r15246, r15248, r15265)
  * Notation: Offer spacing up to 400%%. (r15266)
  * Notation spacing is now saved to the .rg file. (r15269)
  * Fix misc spelling errors flagged by lintian (Bug #1556, r15149)
  * Fix soft synth tracks not responding to volume fader changes.
  (Bug #1557, r15189)
  * Fix Receive External checkbox not cleared. (r15194)
  * Fix key map popup menu position on the Manage MIDI Banks and
  Programs window. Current key map is now under the mouse as it
  should be. (r15221)
  * Fix a memory leak. (r15235)
  * Fix gray leftovers when going out of Archive. (r15240)
  * Fix Track preset name not loaded from .rg file. (r15242)
  * Fix TrackButtons flicker when switching files. (r15244)
  * Fix vertical zoom reset on the Matrix editor. (r15267)
  * Fix vertical zoom reset on the Notation editor. (r15268)
* Mon Jan 29 2018 sndirsch@suse.com
- removed unneeded 'BuildRequires: xorg-x11-util-devel' (bsc#1077489)
* Fri Jan 19 2018 davejplater@gmail.com
- Update to release 17.12 and removed incorporated  svnheader.patch
- Upstream changes:
  * Bug Fixes
  Fix progress dialog lockups in KDE (bug #1546)
  Fix disappearing lyrics in lyrics editor (bug #1547)
  Fix bug #1548: Last syllable of lyrics is not copied between
    two linked segments.
  Fix bug #1550: Crash with lyric editor and linked segments
  Fix bug #1551: No sound from an audio file when pressing rewind
    then play.
  Fix bug #1549: Matrix Editor: Velocity ruler not updated
    correctly when changing velocity using the velocity tool
  Fix alias change not updating label on the audio instrument
    parameters.
  Fix miscellaneous cosmetic issues related to the ThornStyle
    upgrade.
  Fix time mode toolbar buttons on the Event List and other windows.
  Fix incorrect window titles on the preferences and document
    properties windows.
  Fix garbage property names in Event Edit window.
  Display velocities modified from the velocity ruler in the
    status bar for the notation editor.
  Fix bug #1552: Rosegarden fails to build with cmake-3.9.0.
  Fix crash when launching plugin dialog introduced by r14648.
  Fix external controller audio volume/pan bug
  Fix crash in rulers when pressing mouse buttons
  Export to LilyPond as a repeat sequence several consecutive
    linked segments is now possible (bug #1470)
  Fix duplicate connection in initial autoload
  Fix crash when exporting to LilyPond. (bug #1553
  Fix lilypond options dialog too big.
  * New Features
  Add “Use track name for new segments” preference.
* Sat Aug 26 2017 davejplater@gmail.com
- Work around cmake-3.9.0 bug with upstream patch svnheader.patch
- See https://sourceforge.net/p/rosegarden/bugs/1552/ and
  https://gitlab.kitware.com/cmake/cmake/issues/17222.
* Fri Apr 21 2017 davejplater@gmail.com
- Update to release 17.04 codename "Twice in a blue moon".
- Removed rosegarden-fix-crash.patch fix is in this version.
- Rebased rosegarden-10.10-filepaths.patch.
- Upstream changes:
  * Bug Fixes
  * Fix memory leak: delete StartupLogo when closing it.
  * Add compilation fix for Ubuntu 16.04.01 LTS.
  * TrackParameterBox: Fix initial track label problem.
  * Fix #1534: Send channel setup when output is changed.
  * TrackParameterBox: Make color combo visible for audio tracks.
  * autoload: Fix audio track colors.
  * Fix #1532: Crash when trying to edit a triggered segment.
  * Fix #1536: Crash on dangling Instrument IDs.
  * Fix “Always use default studio” stickiness.
  * Fix #1538: No sound when entering notes with keyboard.
  * Fix time stamp bug in MIDI file export.
  * Improve progress dialogs throughout the application.
  * Repair control rulers in Qt 5 builds.
  * Cleanup incorrect name and filter during audio file export.
  * Fix compilation with -DQT_STRICT_ITERATORS.
  * Fix compilation without jack.
  * Enable -DQT_NO_URL_CAST_FROM_STRING and fix compilation
    accordingly.
  * Fix “all piano” issue with empty connections.
  * Fix MIDI import connection problem.
  * Fix a bug in the parallels checker, bug #1544.
  * Fix #1491 Xruns on exit.
  * Fix wait cursor.
  * New Features
  * Hide unused frames for audio tracks in track parameters.
  * Improve handling of collapsing frames in track parameters
    and document properties.
  * Track 20 recent files, rather than 10.
  * Replace stylesheet with custom QStyle.
* Sun Nov 13 2016 davejplater@gmail.com
- Use %%mime_database_post macro instead of calling direct.
* Sun Oct 16 2016 davejplater@gmail.com
- Added rosegarden-fix-crash.patch to fix rosegarden bug:
  https://sourceforge.net/p/rosegarden/bugs/1536/
* Wed Jul 20 2016 davejplater@gmail.com
- Update to release 16.06, codename "Rhapsody in Blue".
- Removed rosegarden-16.02-gcc6.patch, fixed in this version.
- Refreshed rosegarden-10.10-filepaths.patch
- Upstream changes:
  * Bug Fixes
    Avoid deleting softsynths when importing banks
    Avoid drawing segment note previews outside the segment
    borders (#1513).
    Avoid edit views stealing focus from main window in Qt5 (#1508)
    Hide splash screen if still visible when showing file load
    errors.
    Constrain transpose to the usable 0-127 pitch range (#1415).
    The “Accidentals in one bar…” preference is now considered for
    previewing accidentals when inserting notes in notation editor.
    Fix color of cautionary accidental in preview or selection.
    Improve the split and tie long notes at bar lines function to
    cover certain edge cases (#1517).
    Avoid changing stem direction in the middle of a beaming group
    in on-screen rendering or LilyPond export.
    Lilypond export: respect beams for grace notes too. They were
    incorrectly understood as a chord, because they are all at the
    same absolute time.
    Fix undesired channel cleaning at start of second segment
    (#1516).
    AudioPluginManager: Fix broken plugins
    Keep plugins dialog from growing unnecessarily
    Fix selecting legato type would skip to notation on relaunch
    on quantize parameters.
    Fix add articulations wouldn't restore on relaunch in grid
    mode only on quantize parameters.
    Fix channel setup conflicts when daisy chaining
  * New Features
    Lock files so only one Rosegarden instance can edit a particular
    file at any one time.
    New Layer From Selection function to make it easier to resolve
    overlapping polyphonic voices by hand (this function does not
    undo cleanly).
    Multi-track solo mode.
    Archive mode.
* Tue Jun 21 2016 davejplater@gmail.com
- Added upstream rosegarden-16.02-gcc6.patch to fix gcc6 build see
  boo#985242
* Mon Mar 21 2016 davejplater@gmail.com
- Added requires and reccomends for packages needed by rosegarden.
* Sun Mar 20 2016 davejplater@gmail.com
- Enable QT5 build for openSUSE:Leap:42.1
- Remove obsolete Provides for old rosegarden4 and rosegarden-qt4
* Sat Mar 19 2016 crrodriguez@opensuse.org
- make the QT5 switch only In Tumbleweed and future products.
* Fri Mar 18 2016 crrodriguez@opensuse.org
- Build against QT5 in openSUSE 13.2 or later
- Only provide rosegarden-qt4 in old products with QT4.
* Thu Mar  3 2016 davejplater@gmail.com
- Update to version 16.02 codenamed "Querida"
- Now uses cmake to build, adjusted spec file.
- Upstream changes and bug fixes:
  * Bug Fixes
    Fix #1486,involving interacting with the loaded document while
    in the middle of loading a new one.
    Fix scroll bar refresh problem after adding segments.
    Make it possible to disable LIRC, even when it's detected.
    Correct the install location of data files on some platforms
    Fix scrollbar problem after inserting segments
    Fix handling of segment labels when copying/pasting segments
    Reduce number of undo/redo events on the stack for some user
    actions (one action one undo instead of one action two or more
    undos).
    Various tweaking and twiddling of tooltips, context sensitive
    help, and layout spacing.
    Fix notation editor context menu (#1492)
    Fix notation editor crash on double middle click (#1493)
    Fix label issue with drag copy undo. Bug #1450. Undo after
    ctrl+drag copy now restores the proper label to the original
    segment.
    Fix Insert Controller Sequence (Bug #1478) Previously, in the
    NotationView, adding a controller sequence where there were no
    matching controller sequences would reset the start time of the
    segment to 0. Now it leaves the segment start time alone.
    Fix #1478: Segments extended to the beginning after adding
    controller sequence.
    Fix refresh bug introduced by r14441
    At file load time, only a single set of CCs goes out (#1480)
    Add “Allow Reset All Controllers” to preferences. This fixes
    bug #1485 and is related to bug #1480.
    Fix #1504.THRU routing responds to Track Parameters changes
    instantly.
  * New Features
    Add the capability to store any number of comments pages in the
    composition. This allow the translation of the notes displayed
    in a popup dialog when the document is loaded.
    The comment page whose name matches the locale language code is
    displayed.
    Add a French translation to the comment embedded in
    lilypond-alternative-endings_new-way.rg example file.
    When using the mouse to enter notation, you see a preview of
    the note that you will enter if you click the button.
    New mouse quick entry mode:
    The mouse wheel can be used to select the note or rest
    duration.
    A mouse mid click switches between note and rest insert mode
    Holding the Shift key while entering a note adds a sharp
    Holding the Control key while entering a note adds a flat
    Holding Shift + Ctrl while entering a note adds a natural
    Implement track-by-track THRU routing. The Recording filters
    “Thru Routing” field in the Track Parameters box is now fully
    functional.
    The Studio → MIDI Through Routing menu option has been removed.
* Tue Dec 15 2015 davejplater@gmail.com
- Update to version 15.10.2 and refresh patches.
- Upstream changes see http://rosegardenmusic.com/wiki/dev:15.10
* Sat Aug 29 2015 tom.mbrt@googlemail.com
- Update to 14.12:
  + Bug Fixes:
  - Fix translation bug #1423 via patch from Stuart
    Prescott; update all translations. (r13665)
  - Position pointer now moves to the end of paste to
    allow repeated pasting of segments. (r13667)
  - Fix recording of zero-length events (Bug #1365, r13672)
  - Add MuPDF and ePDFView to supported PDF viewers
    (Thomas Kaeding, r13673)
  - Disable destructive actions in playback/record
    (Bug #837, r13676)
  - Numerous fixes to opening http and ftp URLs bydrag/drop.
    With help from Tim Munro. (r13704, r13705, r13706, r13712)
  - Several Qt5 related patches from Tim Munro.
  - Set note-off velocity to 64 as recommended by the MIDI
    spec. (Bug #1426, r13710)
  - Set default volume to 100 in rgd files (r13794)
  - Add support for and prefer xdg-open for opening PDF files
  + New Features:
  - You can enter text dynamics from “d05” to “d125” counting
    by 5 to get these velocities interpreted directly as written
    (Fernando Martin, r13666)
* Sat Nov 29 2014 Led <ledest@gmail.com>
- fix bashisms in scripts
- add patches:
  * rosegarden-14.02-fix-bashisms.patch
* Fri Sep 19 2014 davejplater@gmail.com
- Update to release 14.02 code named "Kaleidoscope"
- Upstream Bug Fixes
  * Fix a transposition bug (Bug #1383, r13540).
  * Fix a bug related to running status and meta events in exported MIDI files
    (r13544)
  * Fix an endless loop with certain MIDI files (Bug #1419, r13550)
  * Pitch tracker patch from Nick Bailey (r13597)
  * Fix a crash when exporting to LilyPond with an empty copyright header
    (r13603)
  * Fix for bad handling of "(c)" in the copyright header when exporting to
    LilyPond (r13603)
  * Fix for handling obscure MIDI files that have an extra unused padding byte
    at the very end (r13604)
  * Fix to allow controllers in zero-length segments to play (r13650)
  * Fix for guessBeats crashes (r13653)
  * Fix for channel allocator waste-minimizer (r13654)
  * Fix to avoid freeing zero-length intervals (r13655)
  * Fix Jump to Quick Marker shortcut, Ctrl+M, in notation (r13656)
  * Fix for first note of a segment playing late (Bug 1378, r13657)
- New Features
  * New auto-expand feature added to the Change Composition Length dialog
    (Feature #417, r13542, r13555).
- New Device Files
  * Casio CTK-3200 device file contributed by Eric (tuxyme)
* Sun Dec 22 2013 zaitor@opensuse.org
- Update to version 13.10:
  + Bugs Fixed:
  - Pitch Bend Sequence Dialog, number of steps must be positive.
  - Fix disconnected move up staff / move down staff commands.
  - Fix sysex import dialog black-on-black problem.
  - Fix for #1372 Rests of new segments don't adapt to time
    signature changes.
  - Fix a refresh bug introduced in r13273 and present in 13.06
    involving deleting contemporaneous segments on a track. This
    may have broken CompositionView refresh in other cases as
    well.
  - Fix UTF8 in track and segment names.
  - Fix the update of notation editors when a track name is
    changed.
  - Fix a "No such key" bug in the key signature dialog.
  - Fix MIDI thru latency issue when recording.
  - Fix repeating segments so they function when overlapping on
    one track.
  - Fix tuplet numbers drawing in black when they should be other
    colors.
  - Fix several interconnected bugs related to MIDI export that
    were causing a variety of problems due to issues with bad
    event ordering and the introduction of spurious controllers.
  - Fix problems when recording past the end of the composition.
  - Fix various crashes when pasting.
  - Fix crash when attempting to import programs from .sfArk
    files (format not supported).
  + New Features:
  - Selection event filter can select rests.
  - Selection event filter can select either performance or
    notation duration.
  - LilyPond export converts a ''(c)'' or a ''(C)'' in the
    copyright header to a proper symbol automatically.
  - New interpretation toolbar for the notation editor
    streamlines the ''**Adjust -> Interpret**'' process.
  - New option to allow LilyPond to export fingerings inside the
    staff (can improve collision resolution).
  - New option to instruct Rosegarden not to start JACK
    automatically at startup, allowing you to control this
    behavior without having to put garbage in your ~/.jackdrc
    file.
  - Support LilyPond 2.14.
  - Added a appdata file.
- Changes from version 13.06:
  + Bugs Fixed:
  - Fix disappearing ties in notation editor.
  - Program changes are now sent on channels for tracks that are
    armed when going into record.
  - CPU usage reduced by almost 50%% when recording MIDI.
  - The range editing commands no longer mess up markers.
  - Fixed an internal leak in the channel allocator.
  - Fixed a crash on paste bug, while revealing other related
    problems that remain to be fixed.
  - Fixed latency compensation in subgroups through a mysterious
    mechanism that seems to work.
  - Fixed a subtle bug involving the drawing of track dividers
    and vertical scrolling.
  - Changing note durations works correctly across barlines. So
    does adding dots to notes.
  - Menu items have a somewhat more consistent style.
  - Certain crashes related to Paste commands shouldn't happen
    any more.
  - The tempo dialog now defaults more sensibly to replacing the
    most recent tempo.
  - Now when you change staffs in the notation editor (with Next
    Staff Down, etc) Rosegarden chooses the next staff more
    sensibly.
  - When you open multiple segments in the notation editor,
    Rosegarden chooses a starting staff more sensibly.
  - Range commands such as edit -> Cut Range now don't split
    segments. Previously only Insert Range kept segments intact.
  - Range commands also try to keep linked segments linked
    together when possible.
  + New Features:
  - Additional work and improvements on the pitchbend sequence
    dialog.
  - Controllers are now easier to place and arrange thru the
    Notation -> Adjust -> controllers -> Insert Controller
    Sequence... menu. The dialog isn't new but it is clearer than
    before and gives you more control over what is placed.
  - "Move to Staff Above" and "Move to Staff Below" now have
    variants that ask what type of pasting to do; formerly it was
    always notation-style pasting.
  - It is now easier to create beat tracks, ie tracks that have a
    note on each beat for use with FitToBeatsCommand and/or
    groove quantize. See [[how_to_make_beat_tracks]].
  - For those users (both of you) who use Segment -> Expand Block
    Chord Segments by Figuration, there is now support for
    figurations without parameter chords.
  - Also for those who use Segment -> Expand Block Chord Segments
    by Figuration, there is Segment -> Update all Figurations,
    which tracks down all regions previously generated from
    figurations and updates them.
  - Ornaments can now be [[how_to_edit_ornaments|inspected and
    edited]] inline, as notation.  Formerly they were only
    available in the Event List Editor.
  - If you want to try to use Rosegarden as a true layered
    editor, ornaments whose trigger consists of tied notes can
    even be set so that only certain sections play.
  - Range commands and other commands that move segments timewise
    are faster now.
* Sun Apr 28 2013 davejplater@gmail.com
- Update to release 13.04 code named "Allysand"
- Upstream bug fixes :
  * Don't export certain properties in MusicXML that MusicXML can't
    handle
  * Fix #1387; export text events (eg. lyrics) to MIDI
  * Fix #703; auto-beaming no longer does an extra unselected bar
  * Fix minor notation layout issue
  * Fix notation scrolling problem
  * Fix bug with FreeChannel
- New features :
  * Choose among 0db, -3dB, -6dB panning laws for audio
* Wed Feb  6 2013 davejplater@gmail.com
- Update to release 12.12.25
- Removed patches rosegarden-10.02-plugin-lib64path.patch,
  rosegarden-gcc47.patch and rosegarden-11.11-gplv2+.patch
  now incorporated upstream.
* Sat Mar 24 2012 dimstar@opensuse.org
- Add rosegarden-gcc47.patch: Fix build with gcc 4.7.
* Wed Mar  7 2012 davejplater@gmail.com
- Fixed Wrong license statement in "About box" and incorect FSF
  address in COPYING with rosegarden-11.11-gplv2+.patch meanwhile
  patch submitted upstream.
* Thu Jan 26 2012 davejplater@gmail.com
- Update to version 11.11.42 as requested.
- For changes visit :
  http://sourceforge.net/projects/rosegarden/files/rosegarden/11.11/
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Dec  1 2011 coolo@suse.com
- set _service to localonly to be acceptable for factory
* Thu May 19 2011 davejplater@gmail.com
- Update to version 11.06, codename "Don Juan".
- Upstream bug Fixes: *A commonly-used time entry widget has had
  it's functionality improved and some usability problems solved.
  * Fixed undo after copying/pasting a range.
  * When adding marks to a selection that includes a mixture of notes
  and rests, avoid applying meaningless marks to the rests.
  * Insert Range now preserves the loop/range.
  * Fixed a LilyPond export bug that caused problems with human
  performances where the notes had a physical start time preceding
  the bar line significantly.
- New features: *the Glasgow Pitch Tracker fork finally merges
  into the new codebase,
  * Expose the instrument alias to external plugin GUIs making
  plugins easier to identify in applications like FLAM.
  * Export LilyPond code using any of LilyPond's supported languages.
* Mon Apr  4 2011 davejplater@gmail.com
- Update to 11.04.12272 Fixes bnc#579168
- For upstrea fixes see :
  /usr/share/doc/rosegarden/CHANGES.txt
* Fri Feb  4 2011 davejplater@gmail.com
- Update to version 11.02, rosegarden-gcc46fix.patch is merged.
- Upstream bug Fixes: *Track numbers are no longer cut off
  * The notation and matrix editors now treat a series of tied
  notes as though it were a single unit, which fixes several
  problems that have been outstanding since as far back as 2002
  * Resizing a segment via click and drag near the edge or with the
  resize tool now leaves that segment as the selected segment
  * When attempting to select a note by clicking toward the extreme
  edges of the note head, it is less likely that you will move the
  note instead of merely selecting it.
  * Insertion / Playback pointer correctly advances in Notation
  editor when entered notes are split and tied.
  * Progress dialogs tweaked to fine tune their behavior.
  * Alt+PgUp and Alt+PgDown now highlight the events in a segment in
  Notation view consistently.
- New Features: *The matrix editor represents tied notes with a
  different fill pattern
  * The split-and-tie long notes option has been made the factory
  default once more, in light of the vastly improved handling of
  ties in the matrix and notation editors.
- Translations complete and uptodate: Spanish French German
- Missing less than 50 translations: Czech (česky)
- Missing less than 100 translations: Japanese Swedish Finnish
- Missing less than 500 translations: Chinese Italian
- Missing more than 1000 translations: Russian Dutch
- Missing more than 2000 translations: Indonesian
- Missing more than 4000 translations: Catalan Welsh Estonian, Basque Polish
* Sat Dec  4 2010 davejplater@gmail.com
- Update to svn snapshot 10.10.12152
- Upstream changes :
  * Italian update by Mario Moles
  * Czech update by Pavel Fric
  * Resizing a segment via click and drag near the edge or with the
  resize tool now leaves that segment as the selected segment.
  * Fixed the grace note bug.
* Wed Nov 24 2010 davejplater@gmail.com
- Update to svn snapshot 10.10.12147
- Upstream changes :
  * ifdef around code that only works in Qt 4.6+
* Tue Nov 23 2010 davejplater@gmail.com
- Update to svn snapshot 10.10.12146
- Added CHANGES.txt and various other text docs
- Upstream changes :
  * fix #3114498
  * patch from J. P. Morris in connection with #3109133
  * Also removing the deprecated constructor in LineEdit
  * Modified the InsertTupletDialog to have SpinBoxes, and also the
  tuplet.png
  * Correct some comments
  * Some layout fixes to TupletDialog and InsertTupletDialog; remove
  redundant includes correct "Insert rest" to "Insert Rest"
  * Adding an insertion mode for general tuplets
  * nice little triplet time beaming incremental improvement from
  Colin Fletcher
  * Holding down Ctrl while dragging in the loop ruler now causes the
  playback position pointer to snap to beat.
  * Enable QGraphicsView::IndirectPainting mode on Panner.
  * Single sweep selecitons are working now.
  * Skip indications in spilt-by-pitch.
  * More work on handling ties in the matrix.
  * A fixed point size of 7 is the number here.My track numbers no
  longer have the top third cut off.
  * Prep for 11.02, I'm guessing.  10.12 might be possible.  We'll go
  with "Claire de Lune" for this one.  "Don Juan" proposed for the
  next one, simply because I used to have a Don Juan rose.  It's a
  good classic red climber.
  * I also fixed a stylesheet issue that I'm not bothering to
  propagate to the stable 10_10 branch.
* Fri Nov  5 2010 davejplater@gmail.com
- Added man page generated by help2man
* Thu Nov  4 2010 davejplater@gmail.com
- Update to release 10.10 and renamed to rosegarden
- Upstream changes :
  * Many fixes to track program/bank behaviour change, save/load and percussion check-box (Julie Swango)
  * Allow shift-click on a track header to toggle segment selection on track without affecting segments (Yves Guillemot)
  * Improve key highlights in matrix view to reflect current segment properly (Julie)
  * Add support for basic LADISH level 1 (Felipe Lopes)
  * Fixed a number of problems with the wrong audio clip being played (Julie)
  * Fix crash when opening file dialog not in  default Thorn style (Chris Cannam and D. Michael McIntyre)
  * Fix incorrect behaviour of frequency-range parameters in LADSPA and DSSI plugin editors (Chris)
  * Fixes to missing-audio-file location logic (Chris)
  * Shorten factory autoload, removing lower sets of tracks all tracks visible (Michael)
  * Fix MIDI recording from devices with note-on and note-off not clean paired (Julie)
  * Fixes to positioning of playback pointer in matrix (Julie)
  * Several large fixes to step-recording in matrix & notation (Julie)
  * Several fixes to Lilypond export (Julie)
  * Many fixes to segment editor to prevent zero-length segments (Ted Felix)
  * Many fixes to prevent zero-length events or ranges (Ted)
  * Fixes to unpredictable behaviour in operations copying segments (Ted)
  * Many fixes to editing operations to stop segment overlap with end of composition (Julie and Ted)
  * Make behaviour of Paste Range more predictable (Ted)
  * Improve chord database and many fixes to fretboard editor (Ted)
  * Fixes to avoid zero-duration note events in files (Michael and Julie)
  * Fixes to toolbar visibility in editing views (Julie)
  * Fixes to regressions in action availability (Ian Gardner)
  * Fixes to updates in notation view (Yves and Julie), event list
  editor (Julie), matrix editor (Julie) and rulers (Julie and Alvar Udras)
  * Restore progress dialogs (Julie)
* Mon Oct 25 2010 davejplater@gmail.com
- Update to svn 12103
- Upstream changes :
  * remove obsolete Japanese translations
  * German update
  * Japanese update...
  * Coding standards.
  * Enormous Chinese update from Rui Fan
* Fri Oct 15 2010 davejplater@gmail.com
- Update to svn 12093
- Upstream changes :
  * Fixed a crash.  Cut an audio segment, delete the underlying
  audio file from the audio file mgr, then paste the audio segment back in.
  * Overhaul encoding selector dialog (used when importing MIDI files
  with non-ASCII text in them).
  * Fixed a crash when pasting audio segments from a previous document.
  * Converted tabs to spaces in Clipboard.cpp.
  * ChordMap no longer writes out corrupt chords.xml files.
* Fri Oct  8 2010 davejplater@gmail.com
- Update to svn 12089
- Upstream changes :
  Update tutorials menu link
  Fixed rescale MIDI segments from the left bug
  patch from Alvar Udras 'notation edit page jumps to right too much' fix
  Resized segments remember their size even when truncated at composition end.
  The ChordMap's "m_needSave" flag is now cleared immediately after
  chords.xml is read to prevent unnecessarily writing the unchanged file
  out.  This avoids a bug in ChordMap::saveDocument() which causes the
  user's local chords.xml file to become corrupt
  ChordMap no longer writes out corrupt chords.xml files.
* Thu Apr 29 2010 davejplater@gmail.com
- Update to 10.04 bugfix release 2.
- Fixes bnc#595479, bnc#574943, bnc#586083 and bnc#599517
- Disabled debug messages
- Upstream fixes :-
  * Fix crash when importing studio from a document that has more MIDI
  devices than the current document
  * Fix crash when inserting a breve at the start of a two-bar 4/4 segment
  * Fix crash when changing synth or plugin settings in a window other
  than the main window, when no synth or audio instrument is assigned in
  the current document but one had been assigned in the previously
  loaded document (#2954068)
  * Fix failure to add tempo changes when asked to do so from the menu,
  in matrix and notation
  * Fix problems mapping international file names to local encoding
  * Fix crash when cancelling file dialogs in some circumstances
  * Fix failure to compile with Qt 4.7
* Sun Apr 25 2010 davejplater@gmail.com
- Update to 10.04 release, removed rosegarden4rpmlintrc and clean up
  spec file.
- Fixes bnc#571481
- This is a bug fix release :-
  * Fixes to crashes and incorrect updating in the notation editor
  * Restore duration-change shortcuts in notation forgotten in 10.02
  * Various small efficiency improvements
  * Fixes to LIRC support
  * Fixed to configure process to permit user override of CXXFLAGS
    and improve platform compatibility
  * Minor improvements to desktop file definition
* Sun Apr 11 2010 davejplater@gmail.com
- Update to rosegarden-10.04, removed patches due to upstream fix :-
  rosegarden-10.02-desktop.patch, rosegarden-10.02-rpmoptflags.patch
  Updated patch rosegarden-10.02-filepaths.patch to
  rosegarden-10.04-filepaths.patch due to source changes.
- Now at svn revision 11865 snapshot.
* Mon Apr  5 2010 davejplater@gmail.com
- Fixed examples, templates and library file paths with
  rosegarden-10.02-filepaths.patch
* Thu Apr  1 2010 davejplater@gmail.com
- Added requires lilypond for 11.3 and requires ladspa
* Sat Feb 20 2010 davejplater@gmail.com
- Cleaned up spec file
* Wed Feb 17 2010 davejplater@gmail.com
- Removed rosegarden wrapper script as it's no longer needed.
* Wed Feb 17 2010 davejplater@gmail.com
- Update to Rosegarden-10.02 release
- Fixes bnc#571474, bnc#571478, bnc#580355, bnc#568658 and
  bnc#566826.
- Rosegarden 10.02 is a complete rewrite and has evolved from a kde3
  application to a stand alone qt4 based application.
  See http://www.rosegardenmusic.com/wiki/dev:10.02 for a full list
  of new features and enhancments.
* Mon Feb 15 2010 davejplater@gmail.com
- Update to svn revision 11820
* Wed Jan 27 2010 davejplater@gmail.com
- Submitted rosegarden-10.02-plugin-lib64path.patch upstream
* Thu Jan 21 2010 davejplater@gmail.com
-Update to svn rev 11681 fix ladspa and dssi plugin search paths with
  rosegarden-10.02-plugin-lib64path.patch
* Wed Jan  6 2010 davejplater@gmail.com
-Update to svn rev 11575 Fix bnc#566826, bnc#564322 and bnc#567555
* Tue Dec 29 2009 davejplater@gmail.com
-Removed rosegarden-10.02-mime-stop.patch due to upstream fix.
* Mon Dec 28 2009 davejplater@gmail.com
-Update to Svn Rev 11521 Save toolbar settings added.
* Sun Dec 27 2009 davejplater@gmail.com
-Created rosegarden-10.02-mime-stop.patch to stop update-mime-database from
  being run by make install
* Fri Dec 25 2009 davejplater@gmail.com
-Update to svn Rev 11509 Rosegarden-qt4 now in the beta stage
  Fixes bnc#549850, bnc#549870, bnc#551644 bnc#551669 and bnc#564295
* Mon Nov  2 2009 davejplater@gmail.com
-Created workaround wrapper script for bnc#549870
-Update to svn revision 11155
* Sat Oct 31 2009 davejplater@gmail.com
-Update to svn revision 11152 to fix bnc#549870
* Tue Oct 20 2009 davejplater@gmail.com
-Update to svn revision 11066
-Added x-rosegarden.desktop and rosegarden.xpm
* Sun Oct 18 2009 davejplater@gmail.com
-Removed rosegarden-mathmeaning.patch due to it's incorporation upsteam
  Now svn revision 11058
* Sun Oct 18 2009 davejplater@gmail.com
-checked in svn revision 11056
* Fri Oct 16 2009 davejplater@gmail.com
-Fixed mathmeaning error with rosegarden-mathmeaning.patch
* Sat Oct 10 2009 davejplater@gmail.com
- packaged rosegarden-qt4 version 10.02 using the buildservice spec file wizard
* Fri Jul 24 2009 tiwai@suse.de
- fix buildrequires: dssi -> dssi-devel
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Wed Feb 18 2009 tiwai@suse.de
- updated to version 1.7.3:
  * bug fix / maintenance release.  See the URL below for details
    http://www.rosegardenmusic.com/wiki/dev:1.7.3
- remove kdemultimedia3-sound from buildrequires (which was
  dropped from FACTORY).
* Mon Jan 19 2009 tiwai@suse.de
- updated to version 1.7.1:
  * Improve resilience of frame - realtime - frame round-trip
    conversions
  * Make it possible to use synth plugins for the metronome
  * Use the name of the segment in the clipboard as the default
  label when adding a new triggered segment via the triggered
  segments manager
  * It is now possible to configure Rosegarden so that it no longer
  appends strings like ”(copied)” and ”(split)” to segments when
  manipulating them
  * Indonesian translation
  * Fix crash when cutting a range
  * Export either fractional or common time signatures to match the
  notation editor, with some minor constraints imposed by
  LilyPond
  * Implement ottava brackets in LilyPond export
  * Export pedal marks as \sustainDown and \sustainUp in LilyPond
  * Distinguish between 8va/8vb and 15ma/15mb a la LilyPond
- updated to version 1.7.2:
  * maintenance release
* Wed Jun 18 2008 tiwai@suse.de
- updated to version 1.7.0:
  * Check headers in Notation view
  * Test to see if a newer version is available
  * New Welcome dialog
  * Notation: The preferred stem direction in a chord around the
    middle line is down
  * Notation: The preferred beam position in a beamed group around
    the middle is below
  * Add icons for Add tempo and Add time signature
  * Move to Staff Above or Staff Below
  * Radically reformed grace notes now work correctly
  * Sync segments to track parameters
  * "Convert notation for..." function added
  * Expanded/corrected instrument presets database
  * Export markers to LilyPond
  * Alternative shortcut for Play/Stop in laptop use: Ctrl+Return
  * New track parameters for exporting square, curly, and nested
    brackets to LilyPond
  * The transport mode setting is now stored with and restored
    from individual compositions
  * Export the new radically reformed grace notes into LilyPond
    syntax
  * Now ties can finally be flipped
  * Arbitrary dynamics exported to LilyPond as markups if they
    are not on LilyPond's list of supported dynamic types
  * Manually repositioned rests (as when rearranging badly
    rendered overlapping voices) are now exported to LilyPond
  * Set a quick playback position marker in the main window with
    Ctrl+1 and recall it with 1
  * New variable height tracks finally make working with
    overlapping segments
  * Smarter selections in matrix and notation views now allow you
    to remove individual, previously-selected events without
    beginning the entire selection process from scratch
* Fri Jan 11 2008 tiwai@suse.de
- updated to version 1.6.1:
  * fixed tempo changes saving
  * fixed the handling of logarithmic control parameters for
    LADSPA and DSSI plugins
* Mon Dec 17 2007 tiwai@suse.de
- updated to version 1.6.0:
  * Diatonic transpose
  * Fretboards
  * Marker ruler usability improvements
  * Multiple lines of lyrics
  * Highlight overlapping notes in notation editor
  * Better LilyPond output dialog, preview through Lilypond,
    print through LilyPond from segment and notation views
  * In-place LilyPond header value editing in LilyPond option dialog
  * Transposition of the staff shown in LilyPond output
  * Show current segment colour in raw note ruler, permit cycling
    through segments on single staff in notation
  * Menus and configuration dialog reorganised for easier access and
    greater clarity
  * Infrared remote control: Support for IRKick
  * Add track(s) in middle
  * Use RTC timer when recent kernel and ALSA versions are detected
  * Expanded documentation
  * Reorganised configuration dialog into standard/advanced options
  * Some revised example files
  * Nice new splash screen
* Wed Nov  7 2007 tiwai@suse.de
- fix build with gcc 4.3.
* Mon Sep  3 2007 schwab@suse.de
- Fix broken compiler flags.
- Fix undefined operation.
* Mon Aug  6 2007 tiwai@suse.de
- add requirement of libsndfile-progs package (#297511)
* Fri Jun 22 2007 tiwai@suse.de
- fix desktop file to make rpmlint happier
* Wed Jun 20 2007 tiwai@suse.de
- fix fdupes usage
* Wed May 23 2007 tiwai@suse.de
- use fdupes to reduce file size
* Thu May  3 2007 wstephenson@suse.de
- fix buildrequires libraptor1-devel -> libraptor-devel
* Thu May  3 2007 lrupp@suse.de
- fix buildrequires raptor-devel -> libraptor1-devel
* Tue Apr 17 2007 tiwai@suse.de
- fix buildrequires ladspa -> ladspa-devel
* Tue Mar 27 2007 tiwai@suse.de
- updated to version 1.5.1:
  * minor bugfix release
* Wed Feb  7 2007 tiwai@suse.de
- updated to version 1.5.0:
  * Add timestretching for audio segments
  * Add import and sample-rate conversion helper for arbitrary
    audio file types
  * Add helpful context help to status bar in track and matrix
    editors
  * Various improvements to the usability and friendliness of
    the matrix editor
  * Add tempo tapping to tempo dialog
  * Further fixes and enhancements to Lilypond export
  * New Invert, Retrograde, Retrograde Invert editing functions
  * Make transport window remember its previous location
  * More helpful warning dialogs on startup if something fails
    to start properly
  * Change build system from scons to cmake
  * Reorganise code into a new directory structure with a far
    more consistent file naming and organisation scheme
- fixed BuildRequires for cmake
- use own *.desktop to avoid nasty problems with
  %%suse_update_desktop_file and the desktop file checker.
* Tue Jan 16 2007 tiwai@suse.de
- fix compilation with RPM_OPT_FLAGS
- fix x = x++ style bugs
* Thu Oct 12 2006 tiwai@suse.de
- updated to version 1.4.0:
  * Multiple MIDI tracks can be recorded
  * A new track parameter box
  * The composition no longer has a fixed duration
  * Special directives in the notation editor can be used
  * Soprano clef has been added
  * Lilypond export now supports LilyPond 2.8
  * Cut, copy and paste "ranges" within a composition
  * Can split selected segments at an arbitrary time
  * Tempos can now be "ramped"
  * The tempo ruler has been overhauled
  * Can zoom in and out of editing views
  * The Panic function is now accessible
  * Can now respond to MMC/MTC
* Fri May 19 2006 tiwai@suse.de
- updated to rosegarden-4-1.2.3:
  * based on scons instead of auto-tools
  * fix for gcc-4.1
  * MTC support
  * improved backend supports
- fixed spec for scons
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 tiwai@suse.de
- disabled mad support (to be distributable)
* Thu Oct 27 2005 stbinner@suse.de
- fix include hints for compilation with Qt 3.3.5
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Wed May 25 2005 adrian@suse.de
- some more gcc4 fixes
* Tue Apr 19 2005 tiwai@suse.de
- another fix for gcc-4.0 (64bit arch).
* Fri Apr 15 2005 tiwai@suse.de
- fixed the build with gcc-4.0.
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Thu Feb 17 2005 adrian@suse.de
- menu entry moved to xdg dir
* Wed Feb 16 2005 tiwai@suse.de
- updated to version 1.0-final.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 1.0pre1.
* Mon Sep  6 2004 tiwai@suse.de
- updated to version 0.9.9.
* Fri Apr 16 2004 tiwai@suse.de
- updated to version 0.9.7.
- disabled the removal of $RPM_BUILD_ROOT in %%install.
* Thu Apr 15 2004 coolo@suse.de
- build without unsermake
* Sun Feb 22 2004 ro@suse.de
- use TOPSUBDIRS instead of SUBDIRS in top Makefile.am
* Mon Feb 16 2004 tiwai@suse.de
- build as non-root.
* Wed Jan 14 2004 tiwai@suse.de
- updated to version 0.9.6.
* Fri Nov  7 2003 ro@suse.de
- fix compilation
* Mon Sep 15 2003 tiwai@suse.de
- build without the optimization.
- fixed the segfault at double-click.
* Tue Aug 12 2003 adrian@suse.de
- add Categories
* Tue Jun 17 2003 kukuk@suse.de
- Fix usage of %%find_lang
* Thu Jun 12 2003 coolo@suse.de
- use %%find_lang
* Fri Jun  6 2003 tiwai@suse.de
- updated to version 0.9.1.
- remove CVS directories in the documentaions.
* Thu Apr 10 2003 ro@suse.de
- updated admin dir
* Tue Feb 25 2003 aj@suse.de
- Add missing assert include.
* Thu Jan 30 2003 tiwai@suse.de
- initial version: 0.8.5.
